@@ -22,6 +22,7 @@
 __author__ = 'j.s@google.com (Jeff Scudder)'
 
 
+import os
 import unittest
 import gdata.gauth
 import gdata.client
@@ -29,45 +30,49 @@ import atom.http_core
 import atom.mock_http_core
 import atom.core
 import gdata.data
+import gdata.core
 # TODO: switch to using v2 atom data once it is available.
 import atom
 import gdata.test_config as conf
 
 
+conf.options.register_option(conf.BLOG_ID_OPTION)
+
+
 class BloggerTest(unittest.TestCase):
 
   def setUp(self):
     self.client = None
-    if conf.settings.RUN_LIVE_TESTS:
+    if conf.options.get_value('runlive') == 'true':
       self.client = gdata.client.GDClient()
-      conf.configure_client(self.client, conf.settings.BloggerConfig, 
-          'BloggerTest')
+      conf.configure_client(self.client, 'BloggerTest', 'blogger')
 
   def tearDown(self):
     conf.close_client(self.client)
 
   def test_create_update_delete(self):
-    if not conf.settings.RUN_LIVE_TESTS:
+    if not conf.options.get_value('runlive') == 'true':
       return
     # Either load the recording or prepare to make a live request.
     conf.configure_cache(self.client, 'test_create_update_delete')
 
     blog_post = atom.Entry(
-        title=atom.Title(text=conf.settings.BloggerConfig.title),
-        content=atom.Content(text=conf.settings.BloggerConfig.content))
+        title=atom.Title(text='test from python BloggerTest'),
+        content=atom.Content(text='This is only a test.'))
     http_request = atom.http_core.HttpRequest()
     http_request.add_body_part(str(blog_post), 'application/atom+xml')
 
     def entry_from_string_wrapper(response):
+      self.assert_(response.getheader('content-type') is not None)
+      self.assert_(response.getheader('gdata-version') is not None)
       return atom.EntryFromString(response.read())
 
     entry = self.client.request('POST', 
         'http://www.blogger.com/feeds/%s/posts/default' % (
-            conf.settings.BloggerConfig.blog_id),
+            conf.options.get_value('blogid')),
          converter=entry_from_string_wrapper, http_request=http_request)
-    self.assertEqual(entry.title.text, conf.settings.BloggerConfig.title)
-    # TODO: uncomment once server bug is fixed
-    #self.assertEqual(entry.content.text, conf.settings.BloggerConfig.content)
+    self.assertEqual(entry.title.text, 'test from python BloggerTest')
+    self.assertEqual(entry.content.text, 'This is only a test.')
 
     # Edit the test entry.
     edit_link = None
@@ -81,8 +86,7 @@ class BloggerTest(unittest.TestCase):
     edited_entry = self.client.request('PUT', edit_link,
          converter=entry_from_string_wrapper, http_request=http_request)
     self.assertEqual(edited_entry.title.text, 'Edited')
-    # TODO: uncomment once server bug is fixed
-    #self.assertEqual(edited_entry.content.text, entry.content.text)
+    self.assertEqual(edited_entry.content.text, entry.content.text)
 
     # Delete the test entry from the blog.
     edit_link = None
@@ -93,7 +97,7 @@ class BloggerTest(unittest.TestCase):
     self.assertEqual(response.status, 200)
 
   def test_use_version_two(self):
-    if not conf.settings.RUN_LIVE_TESTS:
+    if not conf.options.get_value('runlive') == 'true':
       return
     conf.configure_cache(self.client, 'test_use_version_two')
 
@@ -119,7 +123,7 @@ class BloggerTest(unittest.TestCase):
     http_request.add_body_part(entry.to_string(), 'application/atom+xml')
     posted = self.client.request('POST', 
         'http://www.blogger.com/feeds/%s/posts/default' % (
-            conf.settings.BloggerConfig.blog_id),
+            conf.options.get_value('blogid')),
          converter=element_from_string, http_request=http_request)
     # Verify that the blog post content is correct.
     self.assertEqual(posted.get_elements('title', ATOM)[0].text, 'Marriage!')
@@ -134,10 +138,8 @@ class BloggerTest(unittest.TestCase):
         found_tags[0] = True
       elif category.get_attributes('term')[0].value == 'Mr. Darcy':
         found_tags[1] = True
-    self.assertTrue(found_tags[0])
-    self.assertTrue(found_tags[1])
-
-    # TODO: test queries using ETags.
+    self.assert_(found_tags[0])
+    self.assert_(found_tags[1])
 
     # Find the blog post on the blog.
     self_link = None
@@ -147,13 +149,19 @@ class BloggerTest(unittest.TestCase):
         self_link = link.get_attributes('href')[0].value
       elif link.get_attributes('rel')[0].value == 'edit':
         edit_link = link.get_attributes('href')[0].value
-    self.assertTrue(self_link is not None)
-    self.assertTrue(edit_link is not None)
+    self.assert_(self_link is not None)
+    self.assert_(edit_link is not None)
 
     queried = self.client.request('GET', self_link, 
         converter=element_from_string)
     # TODO: add additional asserts to check content and etags.
 
+    # Test queries using ETags.
+    entry = self.client.get_entry(self_link)
+    self.assert_(entry.etag is not None)
+    self.assertRaises(gdata.client.NotModified, self.client.get_entry,
+                      self_link, etag=entry.etag)
+
     # Delete the test blog post.
     self.client.request('DELETE', edit_link)
 
@@ -162,16 +170,15 @@ class ContactsTest(unittest.TestCase):
 
   def setUp(self):
     self.client = None
-    if conf.settings.RUN_LIVE_TESTS:
+    if conf.options.get_value('runlive') == 'true':
       self.client = gdata.client.GDClient()
-      conf.configure_client(self.client, conf.settings.ContactsConfig,
-          'ContactsTest')
+      conf.configure_client(self.client, 'ContactsTest', 'cp')
 
   def tearDown(self):
     conf.close_client(self.client)
 
   def test_crud_version_two(self):
-    if not conf.settings.RUN_LIVE_TESTS:
+    if not conf.options.get_value('runlive') == 'true':
       return
 
     conf.configure_cache(self.client, 'test_crud_version_two')
@@ -198,12 +205,12 @@ class ContactsTest(unittest.TestCase):
         self_link = link.get_attributes('href')[0].value
       elif link.get_attributes('rel')[0].value == 'edit':
         edit_link = link.get_attributes('href')[0].value
-    self.assertTrue(self_link is not None)
-    self.assertTrue(edit_link is not None)
+    self.assert_(self_link is not None)
+    self.assert_(edit_link is not None)
 
     etag = posted.get_attributes('etag')[0].value
-    self.assertTrue(etag is not None)
-    self.assertTrue(len(etag) > 0)
+    self.assert_(etag is not None)
+    self.assert_(len(etag) > 0)
 
     # Delete the test contact.
     http_request = atom.http_core.HttpRequest()
@@ -215,17 +222,21 @@ class VersionTwoClientContactsTest(unittest.TestCase):
 
   def setUp(self):
     self.client = None
-    if conf.settings.RUN_LIVE_TESTS:
+    if conf.options.get_value('runlive') == 'true':
       self.client = gdata.client.GDClient()
       self.client.api_version = '2'
-      conf.configure_client(self.client, conf.settings.ContactsConfig,
-                            'VersionTwoClientContactsTest')
+      conf.configure_client(self.client, 'VersionTwoClientContactsTest', 'cp')
+    self.old_proxy = os.environ.get('https_proxy')
 
   def tearDown(self):
+    if self.old_proxy:
+      os.environ['https_proxy'] = self.old_proxy
+    elif 'https_proxy' in os.environ:
+      del os.environ['https_proxy']
     conf.close_client(self.client)
 
   def test_version_two_client(self):
-    if not conf.settings.RUN_LIVE_TESTS:
+    if not conf.options.get_value('runlive') == 'true':
       return
     conf.configure_cache(self.client, 'test_version_two_client')
 
@@ -238,15 +249,15 @@ class VersionTwoClientContactsTest(unittest.TestCase):
 
     # Create the test contact.
     posted = self.client.post(entry,
-        'http://www.google.com/m8/feeds/contacts/default/full')
-    self.assertTrue(isinstance(posted, gdata.data.GDEntry))
+        'https://www.google.com/m8/feeds/contacts/default/full')
+    self.assert_(isinstance(posted, gdata.data.GDEntry))
     self.assertEqual(posted.get_elements('title')[0].text, 'Test')
     self.assertEqual(posted.get_elements('email')[0].get_attributes(
         'address')[0].value, 'test@example.com')
 
     posted.get_elements('title')[0].text = 'Doug'
     edited = self.client.update(posted)
-    self.assertTrue(isinstance(edited, gdata.data.GDEntry))
+    self.assert_(isinstance(edited, gdata.data.GDEntry))
     self.assertEqual(edited.get_elements('title')[0].text, 'Doug')
     self.assertEqual(edited.get_elements('email')[0].get_attributes(
         'address')[0].value, 'test@example.com')
@@ -254,6 +265,30 @@ class VersionTwoClientContactsTest(unittest.TestCase):
     # Delete the test contact.
     self.client.delete(edited)
 
+  def test_crud_over_https_proxy(self):
+    import urllib
+    PROXY_ADDR = '98.192.125.23'
+    try:
+      response = urllib.urlopen('http://' + PROXY_ADDR)
+    except IOError:
+      return
+    # Only bother running the test if the proxy is up
+    if response.getcode() == 200:
+      os.environ['https_proxy'] = PROXY_ADDR
+      # Perform the CRUD test above, this time over a proxy.
+      self.test_version_two_client()
+
+class JsoncRequestTest(unittest.TestCase):
+
+  def setUp(self):
+    self.client = gdata.client.GDClient()
+
+  def test_get_jsonc(self):
+    jsonc = self.client.get_feed(
+        'http://gdata.youtube.com/feeds/api/videos?q=surfing&v=2&alt=jsonc',
+        converter=gdata.core.parse_json_file)
+    self.assertTrue(len(jsonc.data.items) > 0)
+
 
 # Utility methods.
 # The Atom XML namespace.
@@ -282,8 +317,9 @@ def element_from_string(response):
 
 def suite():
   return conf.build_suite([BloggerTest, ContactsTest, 
-                           VersionTwoClientContactsTest])
+                           VersionTwoClientContactsTest,
+                           JsoncRequestTest])
 
 
 if __name__ == '__main__':
-  unittest.main()
+  unittest.TextTestRunner().run(suite())
